<?php

namespace App\Command\Migration;

use App\Entity\Client;
use App\Entity\Migration\Aulas;
use App\Entity\Migration\Centros;
use App\Entity\Migration\Gruposordenadores;
use App\Entity\Migration\Ordenadores;
use App\Entity\NetworkSettings;
use App\Entity\OrganizationalUnit;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name: 'opengnsys:migration:organizational-unit', description: 'Migration data to new entities')]
class MigrateOrganizationalUnitCommand extends Command
{
    public function __construct(
        private readonly EntityManagerInterface $entityManager,
        private readonly EntityManagerInterface $entityManagerSlave
    )
    {
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $centers = $this->entityManagerSlave->getRepository(Centros::class)->findAll();
        $rooms = $this->entityManagerSlave->getRepository(Aulas::class)->findAll();
        $pcGroups = $this->entityManagerSlave->getRepository(Gruposordenadores::class)->findAll();
        $pcs = $this->entityManagerSlave->getRepository(Ordenadores::class)->findAll();

        $organizationalUnitRepository = $this->entityManager->getRepository(OrganizationalUnit::class);
        $clientRepository = $this->entityManager->getRepository(Client::class);

        /** Centros **/
        $output->writeln("CENTROS TOTAL: ". count($centers));
        foreach ($centers as $center){
            $centerOrganizationalUnit = null;
            $centerOrganizationalUnit = $organizationalUnitRepository->findOneBy(['migrationId' => $center->getIdcentro()]);
            if(!$centerOrganizationalUnit){
                $centerOrganizationalUnit = new OrganizationalUnit();
                $centerOrganizationalUnit->setMigrationId($center->getIdcentro());
                $centerOrganizationalUnit->setName($center->getNombrecentro());
                $centerOrganizationalUnit->setComments($center->getComentarios());
                $this->entityManager->persist($centerOrganizationalUnit);
            }
        }
        $this->entityManager->flush();

        /** Aulas **/
        $output->writeln("AULAS TOTAL: ". count($rooms));
        foreach ($rooms as $room){
            $roomOrganizationalUnit = null;
            $roomOrganizationalUnit = $organizationalUnitRepository->findOneBy(['migrationId' => $room->getIdaula()]);
            if(!$roomOrganizationalUnit){
                $roomOrganizationalUnit = new OrganizationalUnit();
                $roomOrganizationalUnit->setMigrationId($room->getIdaula());
                $roomOrganizationalUnit->setName($room->getNombreaula());
                $roomOrganizationalUnitParent = $organizationalUnitRepository->findOneBy(['migrationId' => $room->getIdcentro()]);
                $roomOrganizationalUnit->setParent($roomOrganizationalUnitParent);
                $this->entityManager->persist($roomOrganizationalUnit);
            }

            $networkSettings = $roomOrganizationalUnit->getNetworkSettings();
            if(!$networkSettings){
                $networkSettings = new NetworkSettings();
                $roomOrganizationalUnit->setNetworkSettings($networkSettings);
                $this->entityManager->persist($networkSettings);
            }
            $networkSettings->setProxy($room->getProxy());
            $networkSettings->setDns($room->getDns());
            $networkSettings->setNetmask($room->getNetmask());
            $networkSettings->setRouter($room->getRouter());
            $networkSettings->setNtp($room->getNtp());
            $networkSettings->setP2pTime($room->getTimep2p());
            $networkSettings->setP2pMode($room->getModp2p());
            $networkSettings->setMcastIp($room->getIpmul());
            $networkSettings->setMcastSpeed($room->getVelmul());
            $networkSettings->setMcastPort($room->getPormul());
            $networkSettings->setMcastMode($room->getModomul());
        }

        $this->entityManager->flush();

        /** Grupo Ordenador **/
        $output->writeln("GRUPOS ORDENADORES ". count($rooms));
        foreach ($pcGroups as $group){
            $groupPcOrganizationalUnit = null;
            $migrateParentId = ($group->getGrupoid() == 0) ? $group->getIdaula() : $group->getGrupoid();
            $groupPcOrganizationalUnit = $organizationalUnitRepository->findOneBy(['migrationId' => $group->getIdgrupo()]);
            if(!$groupPcOrganizationalUnit){
                $groupPcOrganizationalUnit = new OrganizationalUnit();
                $groupPcOrganizationalUnit->setMigrationId($group->getIdgrupo());
                $groupPcOrganizationalUnit->setName($group->getNombregrupoordenador());
                $groupPcOrganizationalUnit->setComments($group->getComentarios());
                $groupPcOrganizationalUnitParent = $organizationalUnitRepository->findOneBy(['migrationId' => $migrateParentId]);
                $groupPcOrganizationalUnit->setParent($groupPcOrganizationalUnitParent);
                $this->entityManager->persist($groupPcOrganizationalUnit);
            }
        }
        $this->entityManager->flush();

        /** Ordenadores **/
        foreach ($pcs as $pc){
            $newClient = $clientRepository->findOneBy(['migrationId' => $pc->getIdordenador()]);
            if(!$newClient){
                $newClient = new Client();
                $newClient->setMigrationId($pc->getIdordenador());
                $this->entityManager->persist($newClient);
            }
            $newClient->setName($pc->getNombreordenador());
            $newClient->setSerialNumber($pc->getNumserie());
            $newClient->setNetiface($pc->getNetiface());
            $newClient->setNetdriver($pc->getNetdriver());
            $newClient->setMac($pc->getMac());
            $newClient->setIp($pc->getIp());
            //$client->setStatus();
            //$newClient->setCache($pc->getCache());
            //$newClient->setIdproautoexec($pc->getIdproautoexec());
            //$newClient->setOglive($pc->getOglivedir());

            // Netboot

            //$migrationId = ""

            // HardwareProfile
            //$hardwareProfile = $hardwareProfileRepository->findOneBy(['migrationId' => $pc->getIdperfilhard()]);
            //$newClient->setHardwareProfile($hardwareProfile);

            // Menu
            //$menu = $menuRepository->findOneBy(['migrationId' => $pc->getIdmenu()]);
            //$newClient->setMenu($menu);

            // Repository
            //$repository = $repositoryRepository->findOneBy(['migrationId' => $pc->getIdrepositorio()]);
            //$newClient->setRepository($repository);

            // OrganizationalUnit
            $migrationId = $pc->getGrupoid() == 0 ? $pc->getIdaula() : $pc->getGrupoid();
            $organizationalUnit = $organizationalUnitRepository->findOneBy(['migrationId' => $migrationId]);
            $newClient->setOrganizationalUnit($organizationalUnit);

        }
        $this->entityManager->flush();

        return 1;
    }
}