<?php

namespace App\Dto\Output;

use ApiPlatform\Metadata\Get;
use App\Entity\User;
use Symfony\Component\Serializer\Annotation\Groups;

#[Get(shortName: 'User')]
final class UserOutput extends AbstractOutput
{
    #[Groups(['user:read'])]
    public string $username;

    #[Groups(['user:read'])]
    public array $roles;

    #[Groups(['user:read'])]
    public bool $enabled;
    #[Groups(['user:read'])]
    public array $allowedOrganizationalUnits;
    #[Groups(['user:read'])]
    public array $userGroups;

    #[Groups(['user:read'])]
    public \DateTime $createAt;

    #[Groups(['user:read'])]
    public ?string $createBy = null;

    public function __construct(User $user)
    {
        parent::__construct($user);

        $this->username = $user->getUsername();
        $this->roles = $user->getRoles();
        $this->enabled = $user->isEnabled();
        $this->userGroups = $user->getUserGroups()->toArray();
        $this->allowedOrganizationalUnits = $user->getAllowedOrganizationalUnits()->toArray();
        $this->createAt = $user->getCreatedAt();
        $this->createBy = $user->getCreatedBy();
    }
}